genesys is a file management and version control software that is directly intigrated with kitsu.

genesys requires a sligthly modified version of zou

docker images of our modified zou[https://hub.docker.com/repository/docker/eaxum/zou] and genesys[https://hub.docker.com/repository/docker/eaxum/genesys] are availble on docker hub

